@@ -4,6 +4,7 @@ module Slop
       help: true,
       tail: false,
       underscore_flags: true,
+      required: false,
     }
 
     # An Array of flags this option matches.
@@ -101,6 +102,11 @@ module Slop
       config[:suppress_errors]
     end
 
+    # Returns true if an exception should be raised when this option isn't supplied.
+    def required?
+      config[:required]
+    end
+
     # Returns all flags joined by a comma. Used by the help string.
     def flag
       flags.join(", ")
