@@ -52,9 +52,8 @@ module Slop
 
         # support `foo=bar`
         orig_flag = flag.dup
-        orig_arg = arg
-        if flag.include?("=")
-          flag, arg = flag.split("=")
+        if match = flag.match(/([^=]+)=([^=]*)/)
+          flag, arg = match.captures
         end
 
         if opt = try_process(flag, arg)
@@ -64,7 +63,7 @@ module Slop
           if opt.expects_argument?
 
             # if we consumed the argument, remove the next pair
-            if orig_arg == opt.value.to_s
+            if consume_next_argument?(orig_flag)
               pairs.delete_at(idx + 1)
             end
 
@@ -80,6 +79,15 @@ module Slop
 
       @arguments += ignored_args
 
+      if !suppress_errors?
+        unused_options.each do |o|
+          if o.config[:required]
+            pretty_flags = o.flags.map { |f| "`#{f}'" }.join(", ")
+            raise MissingRequiredOption, "missing required option #{pretty_flags}"
+          end
+        end
+      end
+
       Result.new(self).tap do |result|
         used_options.each { |o| o.finish(result) }
       end
@@ -97,6 +105,13 @@ module Slop
 
     private
 
+    def consume_next_argument?(flag)
+      return false if flag.include?("=")
+      return true if flag.start_with?("--")
+      return true if /\A-[a-zA-Z]\z/ === flag
+      false
+    end
+
     # We've found an option, process and return it
     def process(option, arg)
       option.ensure_call(arg)
@@ -148,6 +163,7 @@ module Slop
     def partition(strings)
       if strings.include?("--")
         partition_idx = strings.index("--")
+        return [[], strings[1..-1]] if partition_idx.zero?
         [strings[0..partition_idx-1], strings[partition_idx+1..-1]]
       else
         [strings, []]
