@@ -6,6 +6,13 @@ module Slop
     end
   end
 
+  # Cast the option argument to a symbol.
+  class SymbolOption < Option
+    def call(value)
+      value.to_sym
+    end
+  end
+
   # Cast the option argument to true or false.
   # Override default_value to default to false instead of nil.
   # This option type does not expect an argument. However, the API
@@ -44,16 +51,17 @@ module Slop
   # Cast the option argument to an Integer.
   class IntegerOption < Option
     def call(value)
-      value =~ /\A-?\d+\z/ && value.to_i
+      value =~ /\A[+-]?\d+\z/ && value.to_i
     end
   end
   IntOption = IntegerOption
 
   # Cast the option argument to a Float.
   class FloatOption < Option
+    FLOAT_STRING_REGEXP = /\A[+-]?(?:0|[1-9]\d*)(?:\.\d*)?(?:[eE][+-]?\d+)?\z/.freeze
+
     def call(value)
-      # TODO: scientific notation, etc.
-      value =~ /\A-?\d*\.*\d+\z/ && value.to_f
+      value =~ FLOAT_STRING_REGEXP && value.to_f
     end
   end
 
