@@ -36,6 +36,53 @@ describe Slop::Options do
     end
   end
 
+  describe "#separator" do
+    it "appends separators between options in order" do
+      @options.separator("foo")
+      @options.on("--foo")
+      @options.separator("bar")
+
+      assert_equal ["foo", "bar"], @options.separators
+    end
+
+    it "appends strings to the last separator if no options exist" do
+      @options.separator("foo")
+      @options.separator("bar")
+
+      assert_equal ["foo\nbar"], @options.separators
+    end
+
+    it "includes separators in the help text" do
+      @options.on("--foo")
+      @options.separator("bar")
+
+      help = @options.to_s.squeeze(" ")
+      assert help.end_with?("--foo \nbar\n")
+    end
+
+    it "accepts a frozen argument, even when called multiple times for the same option" do
+      @options.separator("foo".freeze)
+      @options.separator("bar".freeze)
+    end
+
+    it "defaults to empty string" do
+      @options.separator
+
+      assert_equal [""], @options.separators
+    end
+
+    it "correctly handles options with `help: false`" do
+      @options.boolean "--opt1"
+      @options.boolean "--opt2", help: false
+      @options.separator "other options"
+      @options.boolean "--opt3", help: false
+      @options.boolean "--opt4"
+
+      _usage, help = @options.to_s.squeeze(" ").split("\n", 2)
+      assert_equal "--opt1 \nother options\n --opt4", help.strip
+    end
+  end
+
   describe "#method_missing" do
     it "uses the method name as an option type" do
       option = @options.string("--name")
@@ -85,11 +132,11 @@ describe Slop::Options do
 
   describe "custom banner" do
     it "is prefixed with defined banner" do
-      @options_config = Slop::Options.new({banner: "custom banner"})
-      assert_match(/^custom banner/, @options_config.to_s) 
+      @options_config = Slop::Options.new(**{banner: "custom banner"})
+      assert_match(/^custom banner/, @options_config.to_s)
     end
     it "banner is disabled" do
-      @options_config = Slop::Options.new({banner: false})
+      @options_config = Slop::Options.new(**{banner: false})
       assert_match("", @options_config.to_s)
     end
   end
