@@ -1,4 +1,5 @@
 require 'test_helper'
+require 'shellwords'
 
 describe Slop::Parser do
   before do
@@ -21,6 +22,20 @@ describe Slop::Parser do
     @result.parser.parse %w(--name=bob -p=123)
     assert_equal "bob", @result[:name]
     assert_equal 123, @result[:port]
+
+    @options.string "--foo"
+    @result.parser.parse %w(--foo = =)
+    assert_equal "=", @result[:foo]
+    assert_equal %w(=), @result.args
+  end
+
+  it "parses flag=''" do
+    @options.string "--str"
+    @options.array "--arr", default: ["array"]
+    @result.parser.parse %(--str="" --arr="").shellsplit
+
+    assert_equal "", @result[:str]
+    assert_equal [], @result[:arr]
   end
 
   it "parses arg with leading -" do
@@ -30,6 +45,12 @@ describe Slop::Parser do
     assert_equal "--sometext", @result[:text]
   end
 
+  it "parses regexp arg with leading -" do
+    @options.regexp "--pattern"
+    @result.parser.parse %w(--pattern -x)
+    assert_equal(/-x/, @result[:pattern])
+  end
+
   it "parses negative integer" do
     @options.integer "-p", "--port"
     @result.parser.parse %w(--name=bob --port -123)
